@@ -1,6 +1,6 @@
 <?php
 $allpages = getAllSlugs ();
-if (containsModule ( get_requested_pagename (), "random_page" ) or isset ( $_GET ["view_random_page"] )) {
+if (containsModule ( get_slug (), "random_page" ) or isset ( $_GET ["view_random_page"] )) {
 	$random = null;
 	do {
 		$random = array_rand ( $allpages, 1 );
